#
# spec file for package digger-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name digger

Name:           digger-cli
Version:        0.6.81
Release:        1.1
Summary:        CLI for the digger open source IaC orchestration tool
License:        Apache-2.0
URL:            https://github.com/diggerhq/digger
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh

%description
CI/CD for Terraform is tricky. To make life easier, specialised CI systems aka
TACOS exist - Terraform Cloud, Spacelift, Atlantis, etc.

But why have 2 CI systems? Why not reuse the async jobs infrastructure with
compute, orchestration, logs, etc of your existing CI?

Digger runs terraform natively in your CI. This is:

* Secure, because cloud access secrets aren't shared with a third-party
* Cost-effective, because you are not paying for additional compute just to run
  your terraform

Features

* Terraform plan and apply in pull request comments
* Private runners - thanks to the fact that there are no separate runners! Your
  existing CI's compute environment is used
* Open Policy Agent (OPA) support for RBAC
* PR-level locks (on top of Terraform native state locks, similar to Atlantis)
  to avoid race conditions across multiple PRs
* Terragrunt, Workspaces, multiple Terraform versions, static analysis via
  Checkov, plan persistence, ...
* Drift detection

This package contains the digger CLI.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1
tar xvf %{SOURCE1} -C ./cli/

%build
cd ./cli/
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X digger/pkg/utils.version=v%{version}" \
   -o ../bin/%{executable_name} ./cmd/digger

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{executable_name}

%changelog
* Mon Dec 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.6.81:
  * add a header for summary comment (#1865)
* Mon Dec 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.6.80:
  * publish ai summaries (#1864)
  * refactor codegen parts (#1863)
  * Create curl_bootstrap.sh
  * restructure docs to have no columns (#1862)
  * Update setup-opentofu to fix issues with 1.6.x downloads (#1861)
  * fix: incorrect comment in backend/migrations (#1860)
  * wip generation of terraform code from application code (#1855)
  * fix/recover from webhook goroutines (#1858)
  * handle crashes in goroutine events (#1857)
  * Update action.yml (#1856)
- Update to version 0.6.79:
  * generation of terraform code from application code by @motatoes
    in #1855
- Update to version 0.6.78:
  * fix/recover from webhook goroutines by @motatoes in #1858
- Update to version 0.6.77:
  * handle crashes in goroutine events by @motatoes in #1857
- Update to version 0.6.76:
  * Update action.yml by @motatoes in #1856
- Update to version 0.6.75:
  * improve efficiency in terragrunt generation (#1854)
  * revert includeparentblocks flag (#1852)
  * add flag to ignore all external directories per project (#1851)
  * suport ignore include blocks for terragrunt (#1849)
  * docs/private runners (#1847)
- Update to version 0.6.74:
  * revert includeparentblocks flag by @motatoes in #1852
- Update to version 0.6.73:
  * add flag to ignore all external directories per project by
    @motatoes in #1851
- Update to version 0.6.72:
  * suport ignore include blocks for terragrunt by @motatoes in
    [#1849]
- Update to version 0.6.71:
  * add flag to limit by number of projects to number of changed
    files (#1846)
  * fix npe in webhook that was accidental (#1845)
- Update to version 0.6.70:
  * make the max number of projects configurable (#1844)
  * Fix drift check logic for no chnages (#1843)
- Update to version 0.6.69:
  * use workflow from project setting (#1841)
  * feat/next config workflows (#1840)
  * regen db following column type change (#1839)
  * use summaryID not job ID (#1838)
- Update to version 0.6.68:
  * fix the nil substitution in %%s (#1837)
- Update to version 0.6.67:
  * ee plan policy in mgmt repo (#1835)
  * upd query name
  * add autoapproval support
- Update to version 0.6.66:
  * handle summary updating when message is too long (#1833)
- Update to version 0.6.65:
  * fix npe on drift-detection for manual job (#1832)
- Update to version 0.6.64:
  * feat/blocks include patterns (#1830)
- Update to version 0.6.63:
  * use hostname in both github and caching (#1831)
- Update to version 0.6.62:
  * added docs about caching
  * add the ability to ignore certain events (#1829)
  * implement caching layer for digger config (#1825)
- Update to version 0.6.61:
  * Removed () (#1827)
  * Need to chech to make sure the StateEnvProvider is set before
    using. (#1826)
- Update to version 0.6.60:
  * no changes
- Update to version 0.6.59:
  * fix conditionals
  * fix conditional
  * fix env variable name
- Update to version 0.6.58:
  * goroutine for issuecomment as well (#1821)
- Update to version 0.6.57:
  * respond immediately to github webhook (#1819)
  * add tests for next (#1818)
- Update to version 0.6.56:
  * Add github connections to EE (#1803)
  * fix(deps): update aws-sdk-go-v2 monorepo (#1551)
  * fix(deps): update github.com/diggerhq/digger/backend digest to
    9a40639 (#1807)
  * fix(deps): update github.com/diggerhq/digger/next digest to
    5834969 (#1808)
  * fix(deps): update module golang.org/x/oauth2 to v0.24.0 (#1562)
  * Update docker/login-action digest to 7ca3450 (#1806)
  * Update github.com/diggerhq/digger/backend digest to 90aa7b8
    (#1565)
  * Update module github.com/hashicorp/go-getter to v2 (#1553)
  * fix(deps): update module cloud.google.com/go/storage to v1.46.0
    (#1552)
  * Update module github.com/spf13/viper to v1.19.0 (#1550)
  * Update module ariga.io/atlas-provider-gorm to v0.5.0 (#1520)
  * add docs for cognito identity token (#1805)
  * Feature:  Adds AWS  Cognito OIDC Support (#1762)
  * fix next deploy (#1804)
  * Update Dockerfile_next (#1773)
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.6.55:
  * feat/configurable initial message (#1802)
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.6.54:
  * set appropriate terragrunt flags (#1801)
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.6.53:
  * report errors back when cannot load digger config (#1800)
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.6.52:
  * Fix workflow file pointer
  * fix: more typos (#1793)
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.6.51:
  * Revert "Revert "Use workflow file in blocks generation""
  * Revert "Use workflow file in blocks generation"
  * Use workflow file in blocks generation
* Tue Nov  5 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.6.50:
  * Dev-Feature: Improve Unit test output and address go-lang
    dependency cache misses on build (#1750)
  * pulumi support in digger (#1790)
  * Allow to use opentofu with generate_projects (#1757)
  * Ensure workflow status failure if command fails in backendless
    mode (#1760)
  * Update docker/login-action digest to 0689575 (#1769)
  * Update variables.mdx (#1774)
  * fix malformed struct tags (#1775)
  * removes unnecessary conditional (#1777)
  * (Typo): Update README.md (#1778)
  * regenerate db models for next (#1788)
* Fri Nov  1 2024 opensuse_buildservice@ojkastl.de
- Update to version latest:
  * use git shell (#1791)
  * run 'go mod tidy' in the cli directory to fix inconsistent
    vendoring (#1789)
* Thu Oct 31 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package digger-cli: open source IaC orchestration tool.
  Digger allows you to run IaC in your existing CI pipeline
